import argparse
import os
from service.parser import ParserHandler
from service.utils.logger import get_logger

logger = get_logger()

API_OPERATIONS = ("get", "post", "put", "patch", "delete", "head", "options", "trace")


def main():
    """Launching function"""
    parser = argparse.ArgumentParser(prog="transform",
                                     description='This tool help to convert any file',
                                     epilog="And that's how you'd like to use this tool")
    parser.add_argument(
            "-t",
            "--team_name",
            help="team name or nfr framework name",
            required=True,
            type=str,
    )
    parser.add_argument(
            "-f",
            "--swagger_path",
            help="path to swagger file or provide swagger api-docs url",
            required=True,
            type=str,
    )
    parser.add_argument(
            "-r",
            "--results-path",
            help="path to store generated nfr framework default: result",
            required=False,
            default='',
            type=str,
    )
    parser.add_argument(
        "-sp",
        "--script-path",
        help="provide script folder path",
        required=False,
        default='',
        type=str
    )
    parser.add_argument(
        "-o",
        "--operations",
        help="operations to use in api testing",
        required=False,
        nargs="+",
        choices=API_OPERATIONS,
        default=[]
    )
    parser.add_argument(
        "-v", "--verbose", help="verbose", required=False, action="store_true", default=False,
    )
    parser.add_argument(
        "-ba", "--blacklist-api", help="tags to use in api testing", required=False, nargs="+", type=str, default=[]
    )
    parser.add_argument(
        "-wa", "--whitelist-api", help="tags to use in api testing", required=False, nargs="+", type=str, default=[]
    )
    args = parser.parse_args()
    logger.debug("Command line args: {}".format(args))
    if args.verbose:
        os.environ["LOG_LEVEL"] = "DEBUG"
    else:
        os.environ["LOG_LEVEL"] = "INFO"
    payload = {
        'team_name': args.team_name,
        'swagger_path': args.swagger_path,
        'results_path': args.results_path,
        'operations': args.operations,
        'blacklist_api': args.blacklist_api,
        'whitelist_api': args.whitelist_api,
        'script_path': args.script_path

    }
    ParserHandler().parser_cli_handler(**payload)


if __name__ == '__main__':
    main()